==> auto-ui-0.3.10.tgz: package/es/switch/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import * as React from 'react';
import A from '../a/index';
import cn from 'classnames';
import IconCheck from '../icon/check';
import IconClose from '../icon/close';
import './style.scss';
var Switch = function (props) {
    var i = props.i, o = props.o, active = props.active, icon = props.icon, disabled = props.disabled, className = props.className, onChange = props.onChange, otherProps = __rest(props, ["i", "o", "active", "icon", "disabled", "className", "onChange"]);
    var composeClassName = cn('x-switch', {
        'x-switch--active': active,
        'x-switch--io': i && o,
        'x-switch--disabled': disabled,
    }, className);
    var hasIO = !!i && !!o;
    var onClick = function () {
        if (disabled) {
            return;
        }
        onChange(!active);
    };
    return (React.createElement(A, __assign({}, otherProps, { className: composeClassName, onClick: onClick }),
        hasIO && React.createElement("sub", null, props.i),
        hasIO && React.createElement("sup", null, props.o),
        React.createElement("em", null,
            icon && !active && React.createElement(IconClose, null),
            icon && active && React.createElement(IconCheck, null))));
};
export default Switch;

==> auto-ui-2.1.28.tgz: package/es/switch/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import IconCheck from '../icon/check';
import IconClose from '../icon/close';
import './style.scss';
var Switch = function (props) {
    var i = props.i, o = props.o, active = props.active, icon = props.icon, disabled = props.disabled, className = props.className, onChange = props.onChange, otherProps = __rest(props, ["i", "o", "active", "icon", "disabled", "className", "onChange"]);
    var composeClassName = cn('x-switch', {
        'x-switch--active': active,
        'x-switch--io': i && o,
        'x-switch--disabled': disabled,
    }, className);
    var hasIO = !!i && !!o;
    var onClick = function () {
        if (disabled || !onChange) {
            return;
        }
        onChange(!active);
    };
    return (React.createElement("button", __assign({}, otherProps, { className: composeClassName, onClick: onClick }),
        hasIO && React.createElement("sub", null, props.i),
        hasIO && React.createElement("sup", null, props.o),
        React.createElement("em", null,
            icon && !active && React.createElement(IconClose, null),
            icon && active && React.createElement(IconCheck, null))));
};
export default Switch;
